==> nextcloud-app-mail-1.11.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/uk.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Автоматичне виявлення не спрацювало. Будь ласка, скористайтесь ручним режимом.",
    "Updating account failed: " : "Оновлення облікового запису не вдалося:",
    "Creating account failed: " : "Помилка створення облікового запису:",
    "Embedded message %s" : "Вбудоване повідомлення %s",
    "Mails" : "Пошта",
    "Mail" : "Пошта",
    "💌 A mail app for Nextcloud" : "💌 Поштовий застосунок для Nextcloud",
    "Auto" : "Автоматично",
    "Name" : "Ім'я",
    "Mail Address" : "Ваш e-mail",
    "Password" : "Пароль",
    "Manual" : "Вручну",
    "IMAP Settings" : "Налаштування IMAP",
    "IMAP Host" : "Вузол IMAP",
    "IMAP Security" : "Безпека IMAP",
    "None" : "Відсутній",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Порт IMAP",
    "IMAP User" : "Користувач IMAP",
    "IMAP Password" : "Пароль IMAP",
    "SMTP Settings" : "Налаштування SMTP",
    "SMTP Host" : "Вузол SMTP",
    "SMTP Security" : "Безпека SMTP",
    "SMTP Port" : "Порт SMTP",
    "SMTP User" : "Користувач SMTP",
    "SMTP Password" : "Пароль SMTP",
    "Save" : "Зберегти",
    "Connect" : "З'єднати",
    "Account settings" : "Налаштування облікового запису",
    "Change name" : "Змінити ім'я",
    "Signature" : "Підпис",
    "A signature is added to the text of new messages and replies." : "Додавати підпис до тексту нових повідомлень та відповідей.",
    "Writing mode" : "Режим редагування",
    "Preferred writing mode for new messages and replies." : "Режим редагування нових повідомлень та відповідей, якому ви віддаєте перевагу.",
    "Mail server" : "Поштовий сервер",
    "Cancel" : "Скасувати",
    "Add mail account" : "Додати обліковий запис",
    "Use Gravatar and favicon avatars" : "Використовувати Gravatar та улюблені піктограми",
    "Register as application for mail links" : "Зробити типовим застосунком ел.пошти",
    "Show keyboard shortcuts" : "Показати гарячі клавіші",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволити застосунку збирати дані про вашу взаємодію. На основі цих даних застосунок буде підлаштовувати видачу. Дані зберігатимуться виключно локально.",
    "From" : "Від",
    "Select account" : "Оберіть обліковий запис",
    "To" : "Кому",
    "Contact or email address …" : "Контакт або ел.адреса...",
    "+ Cc/Bcc" : "+ Cc/Bcc",
    "Cc" : "Копія",
    "No contacts found." : "Відсутні контакти.",
    "Bcc" : "Всс",
    "Subject" : "Тема",
    "Subject …" : "Тема...",
    "This message came from a noreply address so your reply will probably not be read." : "Це повідомлення надійшло з адреси, яка не приймає відповідей, таким чином вашу відповідь можуть не прочитати.",
    "Write message …" : "Написати повідомлення...",
    "Saving draft …" : "Збереження чернетки...",
    "Draft saved" : "Чернетку збережено",
    "Upload attachment" : "Завантажити вкладення",
    "Add attachment from Files" : "Додати вкладення з Файлів",
    "Enable formatting" : "Увімкнути форматування",
    "Uploading attachments …" : "Завантаження вкладень...",
    "Sending …" : "Надсилання...",
    "Error sending your message" : "Помилка під час надсилання повідомлення",
    "Go back" : "Повернутися назад",
    "Retry" : "Ще раз",
    "Message sent!" : "Повідомлення надіслано!",
    "Write another message" : "Написати ще одне повідомлення",
    "Send" : "Надіслати",
    "Encrypt and send" : "Зашифрувати та надіслати",
    "Send unencrypted" : "Надіслати без шифрування",
    "Uploading {percent}% …" : "Завантаження {percent}%...",
    "Choose a file to add as attachment" : "Виберіть файл для вкладення",
    "Choose a file to share as a link" : "Виберіть файл, яким ви поділитеся через посилання",
    "Plain text" : "Простий текст",
    "Rich text" : "Текст з форматуванням",
    "No messages" : "Відсутні повідомлення",
    "Draft: " : "Чернетка:",
    "Mark unimportant" : "Позначити як неважливе",
    "Mark important" : "Позначити як важливе",
    "Mark unread" : "Позначити як не прочитане",
    "Mark read" : "Позначити як прочитане",
    "Mark not spam" : "Позначити як не спам",
    "Mark as spam" : "Позначити як спам",
    "Unselect" : "Зняти виділення",
    "Select" : "Вибрати",
    "Blind copy recipients only" : "Лише отримувачі у прихованій копії",
    "Load more" : "Більше",
    "Report this bug" : "Повідомити про помилку",
    "Could not create event" : "Неможливо створити подію",
    "Could not open mailbox" : "Неможливо відкрити поштову скриньку",
    "Loading messages" : "Завантаження повідомлень",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Індексування повідомлень. Ця дія може забрати більше часу для поштових скриньок з великим обсягом повідомлень.",
    "Choose" : "Вибрати",
    "Favorites" : "Улюблене",
    "Other" : "Інші",
    "Reply" : "Відповісти",
    "Reply to sender only" : "Відповісти лише відправникові",
    "Forward" : "Переслати",
    "View source" : "Джерело",
    "Message source" : "Джерело повідомлення",
    "Import into calendar" : "Імпортувати до календаря",
    "Download attachment" : "Звантажити вкладення",
    "Save to Files" : "Зберегти до Файлів",
    "Unnamed" : "Без назви",
    "Embedded message" : "Вбудоване повідомлення",
    "Choose a folder to store the attachment in" : "Оберіть теку для зберігання вкладень",
    "Save all to Files" : "Зберегти все до Файлів",
    "Choose a folder to store the attachments in" : "Виберіть теку для збереження вкладень",
    "The images have been blocked to protect your privacy." : "Зображення не показуються з міркувань безпеки.",
    "Move" : "Перемістити",
    "New message" : "Нове повідомлення",
    "Settings" : "Налаштування",
    "Quota" : "Обмеження",
    "Saving" : "Збереження",
    "Move down" : "Пересунути вниз",
    "Remove account" : "Вилучити обліковий запис",
    "Loading …" : "Завантаження...",
    "Not supported by the server" : "Не підтримується сервером",
    "{usage} of {limit} used" : "Використано {usage} із {limit}",
    "Remove account {email}" : "Вилучити обліковий запис {email}",
    "Remove {email}" : "Вилучити {email}",
    "Mark all as read" : "Всі прочитані",
    "Edit name" : "Редагувати назву",
    "Clear cache" : "Очистити кеш",
    "_{total} message_::_{total} messages_" : ["{total] повідомлення","{total] повідомлення","{total] повідомлень","{total} повідомлень"],
    "Not found" : "Не знайдено",
    "Could not load your draft" : "Неможливо завантажити чернетку",
    "Could not load original message" : "Неможливо завантажити оригінал повідомлення",
    "No message selected" : "Жодне повідомлення не вибрано",
    "Signature …" : "Підпис...",
    "Save signature" : "Зберегти підпис",
    "Delete" : "Вилучити",
    "Import into {calendar}" : "Імпортувати до {calendar}",
    "Event imported into {calendar}" : "Подію імпортовано до {calendar}",
    "Airplane" : "Літак",
    "Reservation {id}" : "Бронювання {id}",
    "Train" : "Потяг",
    "Mail app" : "Застосунок ел.пошти",
    "Email: {email}" : "Ел.пошта: {email}",
    "General" : "Загальна",
    "IMAP" : "IMAP",
    "User" : "Користувач",
    "Host" : "Хост",
    "Port" : "Порт",
    "SMTP" : "SMTP",
    "Keyboard shortcut" : "Сполучення клавіш",
    "Keyboard shortcuts" : "Гарячі клавіші",
    "Compose new message" : "Нове повідомлення",
    "Newer message" : "Новіші повідомлення",
    "Older message" : "Старіші повідомлення",
    "Toggle star" : "Перемкнути зірочку",
    "Toggle unread" : "Перемкнути непрочитане",
    "Search" : "Пошук",
    "Refresh" : "Оновити",
    "Connect your mail account" : "Приєднати вашу поштову скриньку",
    "Unexpected error during account creation" : "Неочікувана помилка під час створення облікового запису",
    "All" : "Всі",
    "Archive" : "Архів",
    "Drafts" : "Чернетки",
    "Priority inbox" : "Важливі",
    "All inboxes" : "Всі вхідні",
    "Inbox" : "Вхідні",
    "Junk" : "Спам",
    "Sent" : "Надіслані",
    "Trash" : "Кошик",
    "Error while sharing file" : "Помилка під час надання спільного доступу до файлу",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n нове повідомлення\nвід {from}","%n нові повідомлення\nвід {from}","%n нових повідомлень\nвід {from}","%n нових повідомлень\nвід {from}"],
    "Nextcloud Mail" : "Пошта Nextcloud",
    "Could not load your message" : "Неможливо завантажити повідомлення",
    "Could not load the desired message" : "Неможливо завантажити обране повідомлення",
    "Could not load the message" : "Неможливо завантажити повідомлення",
    "Error loading message" : "Помилка завантаження повідомлення.",
    "Forwarding to %s" : "Переслати до %s",
    "Redirect" : "Перенаправлення",
    "The link leads to %s" : "Посилання веде до %s",
    "Continue to %s" : "Перейти до %s"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-app-mail-1.13.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/uk.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Автоматичне виявлення не спрацювало. Будь ласка, скористайтесь ручним режимом.",
    "Updating account failed: " : "Оновлення облікового запису не вдалося:",
    "Embedded message %s" : "Вбудоване повідомлення %s",
    "Important" : "Важливі",
    "Work" : "Робочий",
    "Personal" : "Особисте",
    "Later" : "Пізніше",
    "Mails" : "Пошта",
    "Mail" : "Пошта",
    "💌 A mail app for Nextcloud" : "💌 Поштовий застосунок для Nextcloud",
    "Auto" : "Автоматично",
    "Name" : "Ім'я",
    "Password" : "Пароль",
    "Manual" : "Вручну",
    "IMAP Settings" : "Налаштування IMAP",
    "IMAP Host" : "Вузол IMAP",
    "IMAP Security" : "Безпека IMAP",
    "None" : "Відсутній",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Порт IMAP",
    "IMAP User" : "Користувач IMAP",
    "IMAP Password" : "Пароль IMAP",
    "SMTP Settings" : "Налаштування SMTP",
    "SMTP Host" : "Вузол SMTP",
    "SMTP Security" : "Безпека SMTP",
    "SMTP Port" : "Порт SMTP",
    "SMTP User" : "Користувач SMTP",
    "SMTP Password" : "Пароль SMTP",
    "Connecting" : "Підключення",
    "Save" : "Зберегти",
    "Connect" : "З'єднати",
    "Account settings" : "Налаштування облікового запису",
    "Change name" : "Змінити ім'я",
    "Signature" : "Підпис",
    "A signature is added to the text of new messages and replies." : "Додавати підпис до тексту нових повідомлень та відповідей.",
    "Writing mode" : "Режим редагування",
    "Preferred writing mode for new messages and replies." : "Режим редагування нових повідомлень та відповідей, якому ви віддаєте перевагу.",
    "Mail server" : "Поштовий сервер",
    "Email address" : "Адреса ел.пошти",
    "Cancel" : "Скасувати",
    "Add mail account" : "Додати обліковий запис",
    "Use Gravatar and favicon avatars" : "Використовувати Gravatar та улюблені піктограми",
    "Register as application for mail links" : "Зробити типовим застосунком ел.пошти",
    "Show keyboard shortcuts" : "Показати гарячі клавіші",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволити застосунку збирати дані про вашу взаємодію. На основі цих даних застосунок буде підлаштовувати видачу. Дані зберігатимуться виключно локально.",
    "From" : "Від",
    "Select account" : "Оберіть обліковий запис",
    "To" : "Кому",
    "Contact or email address …" : "Контакт або ел.адреса...",
    "Cc" : "Копія",
    "Bcc" : "Всс",
    "No contacts found." : "Відсутні контакти.",
    "Subject" : "Тема",
    "Subject …" : "Тема...",
    "This message came from a noreply address so your reply will probably not be read." : "Це повідомлення надійшло з адреси, яка не приймає відповідей, таким чином вашу відповідь можуть не прочитати.",
    "Write message …" : "Написати повідомлення...",
    "Saving draft …" : "Збереження чернетки...",
    "Draft saved" : "Чернетку збережено",
    "Upload attachment" : "Завантажити вкладення",
    "Add attachment from Files" : "Додати вкладення з Файлів",
    "Enable formatting" : "Увімкнути форматування",
    "Uploading attachments …" : "Завантаження вкладень...",
    "Sending …" : "Надсилання...",
    "Error sending your message" : "Помилка під час надсилання повідомлення",
    "Go back" : "Повернутися назад",
    "Retry" : "Ще раз",
    "Message sent!" : "Повідомлення надіслано!",
    "Send" : "Надіслати",
    "Encrypt and send" : "Зашифрувати та надіслати",
    "Send unencrypted" : "Надіслати без шифрування",
    "Uploading {percent}% …" : "Завантаження {percent}%...",
    "Choose a file to add as attachment" : "Виберіть файл для вкладення",
    "Choose a file to share as a link" : "Виберіть файл, яким ви поділитеся через посилання",
    "Plain text" : "Простий текст",
    "Rich text" : "Текст з форматуванням",
    "No messages" : "Відсутні повідомлення",
    "Draft: " : "Чернетка:",
    "Unfavorite" : "Не улюблене",
    "Favorite" : "До улюблених",
    "Read" : "Читати",
    "Mark not spam" : "Позначити як не спам",
    "Mark as spam" : "Позначити як спам",
    "Unselect" : "Зняти виділення",
    "Select" : "Вибрати",
    "Edit tags" : "Редагувати мітки",
    "Move" : "Перемістити",
    "More actions" : "Більше дій",
    "Create event" : "Додати подію",
    "Blind copy recipients only" : "Лише отримувачі у прихованій копії",
    "Load more" : "Більше",
    "Report this bug" : "Повідомити про помилку",
    "All day" : "Цілий день",
    "Create" : "Створити",
    "Could not create event" : "Неможливо створити подію",
    "Could not open mailbox" : "Неможливо відкрити поштову скриньку",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Індексування повідомлень. Ця дія може забрати більше часу для поштових скриньок з великим обсягом повідомлень.",
    "Choose" : "Вибрати",
    "Favorites" : "Улюблене",
    "Other" : "Інші",
    "Reply" : "Відповісти",
    "Reply to sender only" : "Відповісти лише відправникові",
    "Forward" : "Переслати",
    "View source" : "Джерело",
    "Message source" : "Джерело повідомлення",
    "Import into calendar" : "Імпортувати до календаря",
    "Download attachment" : "Звантажити вкладення",
    "Save to Files" : "Зберегти до Файлів",
    "Unnamed" : "Без назви",
    "Embedded message" : "Вбудоване повідомлення",
    "Choose a folder to store the attachment in" : "Оберіть теку для зберігання вкладень",
    "Save all to Files" : "Зберегти все до Файлів",
    "Choose a folder to store the attachments in" : "Виберіть теку для збереження вкладень",
    "The images have been blocked to protect your privacy." : "Зображення не показуються з міркувань безпеки.",
    "New message" : "Нове повідомлення",
    "Settings" : "Налаштування",
    "Quota" : "Обмеження",
    "Saving" : "Збереження",
    "Move down" : "Пересунути вниз",
    "Remove account" : "Вилучити обліковий запис",
    "Loading …" : "Завантаження...",
    "Not supported by the server" : "Не підтримується сервером",
    "{usage} of {limit} used" : "Використано {usage} із {limit}",
    "Remove account {email}" : "Вилучити обліковий запис {email}",
    "Remove {email}" : "Вилучити {email}",
    "Mark all as read" : "Всі прочитані",
    "Edit name" : "Редагувати назву",
    "Clear cache" : "Очистити кеш",
    "_{total} message_::_{total} messages_" : ["{total} повідомлення","{total} повідомлення","{total} повідомлень","{total} повідомлень"],
    "No message selected" : "Жодне повідомлення не вибрано",
    "Delete" : "Вилучити",
    "Add" : "Додати",
    "Disabled" : "Вимкнено",
    "Enabled" : "Увімкнено",
    "Signature …" : "Підпис...",
    "Save signature" : "Зберегти підпис",
    "Set" : "Встановити",
    "Unset" : "Зняти",
    "Add tag" : "Додати позначку",
    "Tag already exists" : "Мітка вже існує",
    "Not found" : "Не знайдено",
    "Remove" : "Вилучити",
    "Import into {calendar}" : "Імпортувати до {calendar}",
    "Event imported into {calendar}" : "Подію імпортовано до {calendar}",
    "Airplane" : "Літак",
    "Reservation {id}" : "Бронювання {id}",
    "Train" : "Потяг",
    "Mail app" : "Застосунок ел.пошти",
    "Reset" : "Скидання",
    "Email: {email}" : "Ел.пошта: {email}",
    "General" : "Загальна",
    "IMAP" : "IMAP",
    "User" : "Користувач",
    "Host" : "Хост",
    "Port" : "Порт",
    "SMTP" : "SMTP",
    "Keyboard shortcut" : "Сполучення клавіш",
    "Keyboard shortcuts" : "Гарячі клавіші",
    "Compose new message" : "Нове повідомлення",
    "Newer message" : "Новіші повідомлення",
    "Older message" : "Старіші повідомлення",
    "Toggle star" : "Перемкнути зірочку",
    "Toggle unread" : "Перемкнути непрочитане",
    "Search" : "Пошук",
    "Refresh" : "Оновити",
    "Connect your mail account" : "Приєднати вашу поштову скриньку",
    "All" : "Всі",
    "Archive" : "Архів",
    "Drafts" : "Чернетки",
    "Priority inbox" : "Важливі",
    "All inboxes" : "Всі вхідні",
    "Inbox" : "Вхідні",
    "Junk" : "Спам",
    "Sent" : "Надіслані",
    "Trash" : "Кошик",
    "Error while sharing file" : "Помилка під час надання спільного доступу до файлу",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n нове повідомлення\nвід {from}","%n нові повідомлення\nвід {from}","%n нових повідомлень\nвід {from}","%n нових повідомлень\nвід {from}"],
    "Nextcloud Mail" : "Пошта Nextcloud",
    "Message sent" : "Повідомлення відправлено",
    "Could not load your message" : "Неможливо завантажити повідомлення",
    "Could not load the desired message" : "Неможливо завантажити обране повідомлення",
    "Could not load the message" : "Неможливо завантажити повідомлення",
    "Error loading message" : "Помилка завантаження повідомлення.",
    "Forwarding to %s" : "Переслати до %s",
    "Redirect" : "Перенаправлення",
    "The link leads to %s" : "Посилання веде до %s",
    "Continue to %s" : "Перейти до %s"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
